/*************************************************
 *
 * $GAMGI/src/gtk/light/gamgi_gtk_light_modify.h
 *
 * Copyright (C) 2004 Carlos Pereira
 *
 * Distributed under the terms of the GNU
 * General Public License: $GAMGI/LICENSE
 *
 */

/**********************
 * internal functions *
 **********************

static void static_light (gamgi_window *window);

static void static_default (GtkWidget *widget, void *data);

static void static_reset (gamgi_window *window);

static void static_global (GtkWidget *widget, void *data);

static void static_ok (GtkWidget *widget, void *data);

static void static_init (gamgi_window *window);

static void static_press (gamgi_object *object, void *data);

 **********************
 * external functions *
 **********************/

void gamgi_gtk_light_modify_press (gamgi_window *window_mouse,
GdkEventButton *event, int x, int y, gamgi_window *window_dialog);

void gamgi_gtk_light_modify (GtkWidget *widget, void *data);

/*************
 * Rationale *
 *************

Under development. Global mode not implemented yet.

 *************
 * Rationale *
 *************/
